@@ -3,6 +3,7 @@
 # All rights reserved.
 # This file is distributed under the same license as the current project.
 #
+from copy import deepcopy
 from gettext import gettext as _
 from json import loads, dumps
 from threading import Timer
@@ -18,11 +19,13 @@ class VoskRecognizer(BaseBackend):
     # Счётчик текущих предварительных результатов. Сбрасывается финальным.
     partials_counter = 0
 
-    def __init__(self, settings):
+    def __init__(self, settings, extra=None):
         BaseBackend.__init__(self)
 
         conf = settings.vosk
-        recognizer = conf['recognizer']
+        recognizer = deepcopy(conf['recognizer'])
+        if extra:
+            recognizer.update(extra)
 
         sample_rate_hertz = recognizer['sample_rate_hertz']
         assert sample_rate_hertz in self.HERTZ_LIST
