@@ -98,5 +98,9 @@ class YandexTokenManager(BaseTokenManager):
         )
         if isinstance(token, bytes):
             token = token.decode('utf-8')
-        logger.info(_('Создан новый JWT-токен: %s...%s'), token[:8], token[-8:])
+        logger.info(
+            _('Создан новый JWT-токен: %(start)s...%(end)s'), {
+                'start': token[:8],
+                'end': token[-8:],
+            })
         return token
