@@ -338,7 +338,7 @@ def get_logging_config(work_dir):
         },
         'formatters': {
             'verbose': {
-                'format': '[%(asctime)s] %(levelname)s <%(name)s>: %(message)s'
+                'format': '[%(asctime)s] |%(process)08d| %(levelname)s <%(name)s>: %(message)s'
             },
             # 'short': {
             #     'format': '%(levelname)s <%(name)s>: %(message)s'
