@@ -13,11 +13,12 @@ import subprocess
 import wave
 from collections import OrderedDict
 from datetime import datetime
-from gettext import gettext as _
+from gettext import gettext as _, ngettext
 from os.path import splitext, basename
 from tempfile import NamedTemporaryFile
 from time import time, sleep
 from threading import Thread
+from uuid import uuid4
 
 from astersay.exceptions import AgiError, AgiHangupError, AgiSigpipeError
 
@@ -162,6 +163,7 @@ class BaseDialog:
     _blocklog = None
 
     def __init__(self, agi, settings, stream):
+        self.id = str(uuid4())
         self.agi = agi
         self.settings = settings
         self.stream = stream
@@ -244,17 +246,21 @@ class BaseDialog:
         return regexp.search(text), text
 
     def capture_text(self, stopwords, mode=1, text_buffer=None,
-                     second=0, maxsilence=10, minlength=10):
+                     second=0, maxsilence=10, minlength=10, startsilence=0):
         """Собирает речь вплоть до выявления каких-либо ограничений."""
         if not text_buffer:
             text_buffer = self.get_last_text_buffer()
         text = self.text_from_text_buffer(mode, text_buffer)
         stop = False
+        silence = self.silence_seconds
         if stopwords and stopwords.intersection(text.split(' ')):
             stop = True
             log_debug('Сработало ограничение по стоп-слову.')
+        elif not text and startsilence and silence >= startsilence:
+            stop = True
+            log_debug('Сработало ограничение по изначальной тишине.')
         else:
-            _expire = self.silence_seconds >= maxsilence
+            _expire = silence >= maxsilence
             _size = len(text) >= minlength
             _final = text_buffer.seconds_after_final > 1
             stop = _expire and _size and _final
@@ -314,16 +320,19 @@ class BaseDialog:
             log_error(_('Текст и файл голоса отсутствуют.'))
             return
 
+        synthesis = 0
         # Здесь "voice" - это путь к файлу без его расширения.
         if voice:
             log_info(_('Голос робота: %s'), voice)
         else:
             log_info(_('Текст робота: %s'), text)
+            synthesis_started = time()
             try:
                 voice = self.synthesizer.make_voice(text)
             except Exception as e:
                 log_error(_('Ошибка синтеза речи.'), exc_info=e)
                 return
+            synthesis = time() - synthesis_started
 
         n = 0
         while self._voice and n < 1000:
@@ -377,7 +386,8 @@ class BaseDialog:
         if not disable_blocklog:
             self.blocklog(
                 'robot', text=text, voice=voice, nonblocking=nonblocking,
-                escape_digits=escape_digits, reset_silense=reset_silense)
+                escape_digits=escape_digits, reset_silense=reset_silense,
+                synthesis=synthesis, duration=duration)
 
         self._voice_nonblocking = nonblocking
         if not nonblocking:
@@ -426,7 +436,12 @@ class BaseDialog:
             value = seconds if seconds > 0 else 0
         self.silence_seconds = value
         if value:
-            log_debug(_('Тишина %r секунд.'), value)
+            msg = ngettext(
+                'Тишина %d секунду.',
+                'Тишина %d секунд.',
+                value
+            )
+            log_debug(msg, value)
         return value
 
     def has_start_recognize(self):
@@ -437,6 +452,10 @@ class BaseDialog:
 
     def start_recognizing(self):
         log_debug(_('Включаем передачу голоса на распознавание.'))
+        # Принудительно сбрасываем кол-во секунд тишины, чтобы при быстром
+        # переходе с блока на блок не словить старую паузу.
+        self.silence_seconds = 0
+        self._silence_from = int(time())
         self.recognizer.pause = False
 
     def stop_recognizing(self):
@@ -471,31 +490,44 @@ class BaseDialog:
                 self.calc_silence_seconds()
             thread = self._calc_silence_thread
             self._calc_silence_thread = None
-            log_debug(_('Завершён поток подсчёта тишины %s.'), thread)
+            log_debug(_('Завершён поток подсчёта тишины %s.'), thread.name)
 
         log_debug(_('Запуск отдельного потока подсчёта тишины.'))
         thread = Thread(target=calc_silence, daemon=True)
         thread.start()
-        log_debug(_('Запущен поток подсчёта тишины %s.'), thread)
+        log_debug(_('Запущен поток подсчёта тишины %s.'), thread.name)
         self._calc_silence_thread = thread
 
         def listen():
             # От начала и до конца беседы поток голоса абонента анализируется.
             # Причём, когда объём потока превышает разрешённые 10 мегабайт
             # и парсинг завершается, мы запускаем новый парсинг.
+            recieved = 0
             while self.has_start_recognize():
                 log_debug(_('Запуск recognizer.recognize()'))
-                self.recognizer.listen(self)
+                recognizer = self.recognizer
+                recognizer.listen(self)
+                if hasattr(recognizer, 'listener'):
+                    recieved += recognizer.listener.total_size
+                else:
+                    log_error(_('Слушатель не был подключен.'))
                 log_debug(_('Остановка recognizer.recognize()'))
             thread = self._recognizer_thread
             self._recognizer_thread = None
-            log_debug(_('Завершён поток распознавания %s.'), thread)
+            log_debug(
+                _('Завершён поток распознавания %(name)s. Считано '
+                  'аудио-данных: %(recieved)d байт.'),
+                {
+                    'name': thread.name,
+                    'recieved': recieved,
+                }
+            )
 
         self.is_closed = False
         log_debug(_('Запуск отдельного потока распознавания.'))
         thread = Thread(target=listen, daemon=True)
         thread.start()
-        log_debug(_('Запущен поток распознавания %s.'), thread)
+        log_debug(_('Запущен поток распознавания %s.'), thread.name)
         self._recognizer_thread = thread
         return thread
 
@@ -559,6 +591,7 @@ class BaseDialog:
 
         filename = self.settings.export_dialog(
             self.agi.params, self.export, self.text_buffers,
+            dialog_id=self.id,
             hangup=hangup,
             error=error,
             chain=self.chain,
@@ -586,6 +619,7 @@ class BaseDialog:
         plugin = self.settings.get_plugin(name)
         log_debug('> PLUGIN %s', plugin)
         plugin_data = {
+            'dialog_id': self.id,
             'agi_params': self.agi.params,
             'work_dir': self.settings.work_dir,
             'speech': speech,
@@ -694,6 +728,8 @@ class BaseDialog:
 
             # Сбрасываем логгирование для блока (скрипта).
             self._blocklog = None
+            block_start = time()
+            self.blocklog('block_start')
 
             debug_msg = '  SCRIPT %s'
             debug_args = [name.upper()]
@@ -723,6 +759,7 @@ class BaseDialog:
                 self.say(**make_say_params(saydata, variables))
 
             result, speech = method(script, variables)
+            self.blocklog('block_result')
             log_debug('  RESULT %r', result)
             log_debug('  SPEECH %r', speech)
             # Экспортируем разговор в отдельную переменную, чтобы иметь
@@ -792,6 +829,8 @@ class BaseDialog:
             # Восстанавливаем константы. Это проще, чем городить лес кода.
             variables.update(constants)
             # Сохраняем цепочку вызовов скриптов.
+            block_finish = time()
+            self.blocklog('block_finish', duration=(block_finish - block_start))
             chain.append([name, result, speech, self._blocklog])
 
         log_debug(_('Главный скрипт завершён.'))
@@ -881,10 +920,12 @@ class BaseDialog:
         maxtime = float(script.get('maxtime', 600))
         minlength = int(script.get('minlength', 10))
         maxsilence = int(script.get('maxsilence', 10))
+        startsilence = int(script.get('startsilence', 0))
         stopwords = script.get('stopwords', [])
         log_debug(_('Ограничение по времени: %s секунд.'), maxtime)
         log_debug(_('Ограничение по длине: от %s символов.'), minlength)
-        log_debug(_('Ограничение по тишине: %s секунд.'), stopwords)
+        log_debug(_('Ограничение по тишине: %s секунд.'), maxsilence)
+        log_debug(_('Ограничение по тишине в начале: %s секунд.'), startsilence)
         log_debug(_('Ограничение по стоп-словам: %s.'), stopwords)
         stopwords = set(stopwords)
 
@@ -896,6 +937,7 @@ class BaseDialog:
             second=0,
             maxsilence=maxsilence,
             minlength=minlength,
+            startsilence=startsilence,
         )
         if stop:
             log_debug(_('Первая попытка успешна. Текст: %s'), speech)
@@ -1350,10 +1392,11 @@ class BaseDialog:
         if 'export_name' in script:
             export_name = script['export_name']
             assert export_name and isinstance(export_name, str)
-            if 'export_value' in script:
-                variables[export_name] = script['export_value']
-            elif 'initial_value' in script:
+            if 'initial_value' in script:
                 variables[export_name] = script['initial_value']
+            # TODO: удалить в версии 0.30.
+            elif 'export_value' in script:
+                variables[export_name] = script['export_value']
 
         pauses = script.get('pauses', {})
         make_pause(pauses, 'before')
