@@ -19,6 +19,7 @@ with open(filename) as f:
 #######################
 
 # Словарь plugin_data содержит:
+# 'dialog_id' - UUID диалога с виде строки с дефисами,
 # 'agi_params' - все переменные переданные в EAGI,
 # 'work_dir' - путь к рабочему каталогу,
 # 'speech' - распознанная речь текущего блок-скрипта,
@@ -29,6 +30,7 @@ with open(filename) as f:
 # 'config': словарь дополнительных параметров для плагина,
 
 print('Получены данные для плагина.')
+print('dialog_id:', plugin_data['dialog_id'])
 print('agi_params:', plugin_data['agi_params'])
 print('work_dir:', plugin_data['work_dir'])
 print('speech:', plugin_data['speech'])
